"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
require("mocha"); // tslint:disable-line:no-import-side-effect
var assert = require("power-assert");
var testEntity_1 = require("../../tests/utils/testEntity");
var createCursorFromEntity_1 = require("../createCursorFromEntity");
var index_1 = require("./index");
describe('createCursorFromEntity', function () {
    var sort = { id: true, booleanProp: false };
    it('should return empty filter when the cursor is undefined', function () {
        var pagination = { cursor: undefined, forward: true, limit: 1 };
        var actualResult = index_1.default(pagination, sort);
        var expectedResult = {};
        assert.deepEqual(actualResult, expectedResult);
    });
    it('should return the correct filter when the cursor is defined and going forward', function () {
        var cursor = createCursorFromEntity_1.default(testEntity_1.testEntity, sort);
        var pagination = { cursor: cursor, forward: true, limit: 1 };
        var actualResult = index_1.default(pagination, sort);
        var expectedResult = {
            booleanProp: { $lte: testEntity_1.testEntity.booleanProp },
            id: { $gt: testEntity_1.testEntity.id },
        };
        assert.deepEqual(actualResult, expectedResult);
    });
    it('should return the correct filter when the cursor is defined and going backward', function () {
        var cursor = createCursorFromEntity_1.default(testEntity_1.testEntity, sort);
        var pagination = { cursor: cursor, forward: false, limit: 1 };
        var actualResult = index_1.default(pagination, sort);
        var expectedResult = {
            booleanProp: { $gte: testEntity_1.testEntity.booleanProp },
            id: { $lt: testEntity_1.testEntity.id },
        };
        assert.deepEqual(actualResult, expectedResult);
    });
});
//# sourceMappingURL=index.test.js.map